#
# spec file for package qt6-serialport
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.2.2
%define short_version 6.2
%define tar_name qtserialport-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor docs%{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-serialport%{?pkg_suffix}
Version:        6.2.2
Release:        bp154.1.66
Summary:        Qt 6 SerialPort library
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source:         https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-serialport-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  pkgconfig(libudev)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
Qt 6 SerialPort library

%if !%{qt6_docs_flavor}

%package -n libQt6SerialPort6
Summary:        Qt 6 SerialPort library

%description -n libQt6SerialPort6
The Qt SerialPort library provides the basic functionality, which includes
configuring, I/O operations, getting and setting the control signals
of the RS-232 pinouts. This module does not support terminal features
(echo, CR/LF control, text mode, timeouts/delays, or poinout signal
change notification).

%package devel
Summary:        Qt 6 SerialPort library - Development files
Requires:       libQt6SerialPort6 = %{version}
Requires:       cmake(Qt6Core)

%description devel
Development files for the Qt 6 SerialPort library.

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 SerialPort library
Requires:       cmake(Qt6SerialPort) = %{real_version}
%requires_eq     qt6-core-private-devel

%description private-devel
This package provides private headers of libQt6SerialPort that do not have any
ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

%post -n libQt6SerialPort6 -p /sbin/ldconfig
%postun -n libQt6SerialPort6 -p /sbin/ldconfig

%files -n libQt6SerialPort6
%license LICENSE.*
%{_qt6_libdir}/libQt6SerialPort.so.*

%files devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtSerialPortTestsConfig.cmake
%{_qt6_cmakedir}/Qt6SerialPort/
%{_qt6_descriptionsdir}/SerialPort.json
%{_qt6_includedir}/QtSerialPort/
%{_qt6_libdir}/libQt6SerialPort.prl
%{_qt6_libdir}/libQt6SerialPort.so
%{_qt6_metatypesdir}/qt6serialport_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_serialport.pri
%exclude %{_qt6_includedir}/QtSerialPort/%{real_version}/

%files private-devel
%dir %{_qt6_includedir}/QtSerialPort
%{_qt6_includedir}/QtSerialPort/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_serialport_private.pri

%endif

%changelog
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Sat Feb  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-serialport
